@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # filename: formats/leica_tcr_705.py
-# Copyright 2009-2010 Stefano Costa <steko@iosa.it>
+# Copyright 2026 Stefano Costa <steko@iosa.it>
 # Copyright 2009-2010 Luca Bianconi <luxetluc@yahoo.it>
 
 # This file is part of Total Open Station.
@@ -54,9 +54,9 @@ class FormatParser(Parser):
         else:
             text = ""
 
-        p = Point(tokens[1],
-                  tokens[2],
-                  tokens[3])
+        p = Point(float(tokens[1]),
+                  float(tokens[2]),
+                  float(tokens[3]))
         f = Feature(p,
                     desc=text,
                     id=tokens[0].strip())
