@@ -17,6 +17,7 @@ class TestGeoJSONOutput(unittest.TestCase):
         ]
 
     def test_output(self):
+        self.maxDiff = None
         self.output = OutputFormat(self.data).process()
-        ref_output = '''{"type": "FeatureCollection", "bbox": [12.8, 26.3, 56.2, 19.8], "features": [{"bbox": [12.8, 76.3, 56.2, 12.8, 76.3, 56.2], "geometry": {"type": "Point", "coordinates": [12.8, 76.3, 56.2]}, "type": "Feature", "properties": {"desc": "TEST POINT"}, "id": 1}, {"bbox": [19.8, 26.3, 46.2, 19.8, 26.3, 46.2], "geometry": {"type": "Point", "coordinates": [19.8, 26.3, 46.2]}, "type": "Feature", "properties": {"desc": "TEST POINT #2"}, "id": 2}]}'''
+        ref_output = '''{"type": "FeatureCollection", "bbox": [12.8, 26.3, 19.8, 76.3], "features": [{"type": "Feature", "bbox": [12.8, 76.3, 12.8, 76.3], "geometry": {"type": "Point", "bbox": [12.8, 76.3, 12.8, 76.3], "coordinates": [12.8, 76.3, 56.2]}, "properties": {"desc": "TEST POINT"}, "id": 1}, {"type": "Feature", "bbox": [19.8, 26.3, 19.8, 26.3], "geometry": {"type": "Point", "bbox": [19.8, 26.3, 19.8, 26.3], "coordinates": [19.8, 26.3, 46.2]}, "properties": {"desc": "TEST POINT #2"}, "id": 2}]}'''
         self.assertEqual(json.loads(self.output), json.loads(ref_output))
